@@ -4,6 +4,7 @@ from typing import AsyncGenerator, Callable, Dict, List, Optional, Tuple
 
 import httpx
 
+from omegacloud_cli import __version__
 from omegacloud_cli.common.enums import JobTypeEnum
 from omegacloud_cli.common.schemas import (
     AgentInitRequestModel,
@@ -17,7 +18,7 @@ from omegacloud_cli.controllers.filesync import (
     FilesSyncModel,
     FileSyncManager,
 )
-from omegacloud_cli.utils import load_config
+from omegacloud_cli.utils.config import load_config
 
 PLATFORM_URL = load_config("platform_url").rstrip("/")
 
@@ -27,6 +28,7 @@ def get_headers() -> Dict[str, str]:
     headers = {}
     if token := load_config("apikey"):
         headers["Authorization"] = f"Bearer {token}"
+    headers["X-OmegaCloud-CLI-Version"] = __version__
     return headers
 
 
@@ -256,7 +258,7 @@ async def sync_files_api(
             url,
             json=client_snapshot.model_dump(mode="json"),
             headers=get_headers(),
-            params={"storage_name": storage_name},
+            params={"storage_name": FileSyncManager.encode_path(storage_name)},
         )
         response.raise_for_status()
         return FilesSyncModel.model_validate(response.json())
@@ -288,7 +290,7 @@ async def upload_file_api(
         result = await FileSyncManager.upload_file(
             url,
             get_headers(),
-            {"storage_name": storage_name},
+            {"storage_name": FileSyncManager.encode_path(storage_name)},
             storage_path,
             file_path,
             progress_callback=progress_callback,
@@ -322,7 +324,7 @@ async def download_file_api(
         result = await FileSyncManager.download_file(
             url,
             get_headers(),
-            {"storage_name": storage_name},
+            {"storage_name": FileSyncManager.encode_path(storage_name)},
             storage_path,
             file_path,
             progress_callback=progress_callback,
