@@ -8,6 +8,7 @@ from datetime import datetime
 from enum import Enum
 from functools import wraps
 from typing import Callable, Dict, List, Optional, Tuple, Union
+import toml
 
 import asyncclick as click
 import httpx
@@ -15,11 +16,13 @@ from cron_descriptor import get_description as get_schedule_description
 from croniter import croniter
 from InquirerPy import get_style, inquirer
 from InquirerPy.base.control import Choice
+from packaging import version
 from rich.console import Console
+from rich.panel import Panel
 from rich.progress import Progress, TaskID
 from rich.status import Status
 
-from omegacloud_cli import api
+from omegacloud_cli import __version__, api
 from omegacloud_cli.common.enums import (
     AgentStatusEnum,
     JobStatusEnum,
@@ -31,7 +34,13 @@ from omegacloud_cli.common.schemas import (
     TaskStatusResponseModel,
 )
 from omegacloud_cli.controllers.filesync import FileSyncManager
-from omegacloud_cli.utils import load_config, load_script, save_config, save_script
+from omegacloud_cli.utils.config import (
+    load_config,
+    load_script,
+    save_config,
+    save_script,
+)
+from omegacloud_cli.utils.schedule import cron_to_celery_cron
 
 # Command aliases
 ALIASES = {
@@ -47,12 +56,66 @@ style = get_style({"question": "bold"}, style_override=False)
 console = Console()
 
 
+def check_for_updates_wrapper(func):
+    """Check for updates to the CLI."""
+
+    def display_update_notification(latest_version: str):
+        """Display update notification."""
+        current_version = __version__
+        console.print()
+        console.print(
+            Panel(
+                f"[bold]OmegaCloud CLI update available!   v{current_version} ≫ v{latest_version}[/]\n"
+                # f"Changelog: [link=https://github.com/omegacloud/omegacloud-cli/releases]https://github.com/omegacloud/omegacloud-cli/releases[/]\n"
+                f"To update, run:   [bold]pip install --upgrade omegacloud-cli[/]",
+                title="Update Available",
+                border_style="green",
+                expand=False,
+            )
+        )
+        console.print()
+
+    @wraps(func)
+    async def wrapper(*args, **kwargs):
+        """Check for updates to the CLI."""
+
+        fnc_result = await func(*args, **kwargs)
+
+        latest_version = None
+        try:
+            with httpx.Client() as client:
+                response = client.get("https://pypi.org/pypi/omegacloud-cli/json")
+                if response.status_code == 200:
+                    latest_version = response.json()["info"]["version"]
+                    current_version = __version__
+
+                    if version.parse(latest_version) > version.parse(current_version):
+                        display_update_notification(latest_version)
+        except Exception:
+            pass
+
+        return fnc_result
+
+    return wrapper
+
+
 def try_except_wrapper(func):
     """
     A decorator that wraps functions with common error handling logic.
     Handles KeyboardInterrupt, CancelledError, HTTPStatusError, ConnectError and general exceptions.
     """
 
+    def extract_error_message(e: Exception) -> str:
+        if hasattr(e, "response") and hasattr(e.response, "text"):
+            error_text = e.response.text
+            try:
+                error_json = json.loads(error_text)
+                return error_json.get("detail", str(e))
+            except json.JSONDecodeError:
+                return error_text
+        else:
+            return str(e)
+
     @wraps(func)
     async def wrapper(*args, **kwargs):
         try:
@@ -65,17 +128,17 @@ def try_except_wrapper(func):
             if e.response.status_code in [401, 403]:
                 console.print("[red]Authentication failed. Please login by > omega login.[/]")
             elif e.response.status_code in [500]:
-                console.print(f"[red]An error occurred: {str(e)}[/]")
+                console.print(f"[red]An error occurred: {extract_error_message(e)}[/]")
             else:
-                console.print(f"[red]An error occurred: {str(e)}[/]")
+                console.print(f"[red]An error occurred: {extract_error_message(e)}[/]")
             raise click.Abort()
         except httpx.ConnectError as e:
             console.print(
-                f"[red]Omega Platform is now unavailable. Please try again later. {str(e)}[/]"
+                f"[red]Omega Platform is now unavailable. Please try again later. {extract_error_message(e)}[/]"
             )
             raise click.Abort()
         except Exception as e:
-            console.print(f"[red]An error occurred: {str(e)}[/]")
+            console.print(f"[red]An error occurred: {extract_error_message(e)}[/]")
             raise click.Abort()
 
     return wrapper
@@ -106,12 +169,13 @@ def cli():
     """
     OmegaCloud: One-click platform for AI-apps deployment
 
-    CLI version: v.0.1.6 / for update: pip install --upgrade omegacloud-cli
+    CLI version: v.0.1.13 / for update: pip install --upgrade omegacloud-cli
     """
     pass
 
 
 @cli.command(name="login", help="Login to Omega Cloud")
+@check_for_updates_wrapper
 async def cli_login():
     """Login to Omega Cloud."""
     await login_flow()
@@ -119,6 +183,7 @@ async def cli_login():
 
 @cli.command(name="run", help="Run a new Job | aliases: start")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_run():
     """Start a new job"""
@@ -128,6 +193,7 @@ async def cli_run():
 
 @cli.command(name="stop", help="Stop a running job")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_stop():
     """Stop a running job."""
@@ -137,6 +203,7 @@ async def cli_stop():
 
 @cli.command(name="inspect", help="Get status of a job | aliases: status")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_inspect():
     """Get status of a job."""
@@ -146,6 +213,7 @@ async def cli_inspect():
 
 @cli.command(name="watch", help="Watch logs from the job | aliases: logs")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_watch():
     """Watch logs from the job."""
@@ -155,6 +223,7 @@ async def cli_watch():
 
 @cli.command(name="sync", help="Synchronize files | aliases: files")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_sync():
     """Synchronize files with the job."""
@@ -168,6 +237,7 @@ async def cli_sync():
 
 @cli.command(name="config", help="Configure Omega Run")
 @check_auth_wrapper
+@check_for_updates_wrapper
 @try_except_wrapper
 async def cli_config():
     """Configure CLI parameters."""
@@ -303,12 +373,12 @@ async def sync_flow(status: Status, sync_type: str, operations: str = "upload+do
                     Choice(value="all", name="Proceed with sync"),
                     Choice(value="download", name="Download only"),
                     Choice(value="upload", name="Upload only"),
-                    Choice(value="cancel", name="Cancel"),
+                    Choice(value="cancel", name="Do not sync"),
                 ]
             else:
                 choices = [
                     Choice(value="all", name="Proceed with sync"),
-                    Choice(value="cancel", name="Cancel"),
+                    Choice(value="cancel", name="Do not sync"),
                 ]
 
             # Use the async version of select
@@ -498,9 +568,9 @@ async def inspect_flow(status: Status):
             or not agent_info.agent_status
             or agent_info.agent_status in [AgentStatusEnum.DEAD]
         ):
-            console.print("[red]No active environment found[/]")
+            console.print("[red]No active server found[/]")
         elif agent_info.agent_status in [AgentStatusEnum.INIT]:
-            console.print("[yellow]Application is initializing[/]")
+            console.print("[yellow]Server is initializing[/]")
         elif agent_info.agent_status in [AgentStatusEnum.IDLE]:
             console.print("[yellow]Application is not running[/]")
         elif agent_info.agent_status in [AgentStatusEnum.BUSY]:
@@ -511,7 +581,7 @@ async def inspect_flow(status: Status):
 
         for key, val in info_dict.items():
             title = key.replace("_", " ").title()
-            title = title.replace("Agent", "Environment")
+            title = title.replace("Agent", "Server")
             value = val.value.upper() if isinstance(val, Enum) else val
             if "logs" not in key:
                 if value:
@@ -656,7 +726,7 @@ async def schedule_flow() -> str:
 
     # Load task.sh script for user display
     # script = load_script("task.sh")
-    # task_command = "; ".join(script) if script else "python main.py"
+    # task_command = "& ".join(script) if script else "python main.py"
 
     # # Ask user to input task run command
     # task_command = await inquirer.text(
@@ -666,7 +736,7 @@ async def schedule_flow() -> str:
     # ).execute_async()
 
     # # Split command by ; and clean up whitespace
-    # commands = [cmd.strip() for cmd in task_command.split(";")]
+    # commands = [cmd.strip() for cmd in task_command.split("&")]
     # save_script("task.sh", commands)
 
     return job_schedule
@@ -685,6 +755,8 @@ async def commands_flow(job_type: JobTypeEnum):
     run_commands = []
     task_commands = []
 
+    framework = autodetect_framework()
+
     job_schedule = load_config("job_schedule")
 
     # Needs for API
@@ -699,8 +771,7 @@ async def commands_flow(job_type: JobTypeEnum):
         build_commands = load_script("build.sh")
         if not build_commands:
             build_commands = autodetect_build_commands()
-        build_command = "; ".join(build_commands)
-        framework = autodetect_framework()
+        build_command = "& ".join(build_commands)
         if framework == "node":
             console.print()
             console.print(
@@ -713,45 +784,60 @@ async def commands_flow(job_type: JobTypeEnum):
             style=style,
             default=build_command,
         ).execute_async()
-        build_commands = [cmd.strip() for cmd in build_command.split(";")]
+        build_commands = [cmd.strip() for cmd in build_command.split("&")]
 
-    if (job_type in JobTypeEnum.API) or (not job_schedule):
+    if (job_type == JobTypeEnum.API) or (job_type == JobTypeEnum.JOB and not job_schedule):
         # Asking for run commands for API/WEB applications or JOB without schedule (one-time job)
         run_commands = load_script("run.sh")
         if not run_commands:
             run_commands = await autodetect_run_commands()
-        run_command = "; ".join(run_commands)
+        run_command = "& ".join(run_commands)
 
         # Ask user to input app run command
         if job_type in JobTypeEnum.API:
             console.print()
             console.print("[bold]Important![/] Run your API/WEB on [bold]8008[/] port!")
 
+        available_scripts = None
         if framework == "node":
-            node_scripts = get_node_scripts()
+            available_scripts = get_node_scripts()
+        
+        run_script = "custom"
+
+        if available_scripts:
             # select script
-            choices = [Choice(value=k, name=f"{k}: {v}") for k, v in node_scripts.items()]
-            run_command = await inquirer.select(
+            choices = [Choice(value=k, name=f"{k}: {v}") for k, v in available_scripts.items()]
+            choices.append(Choice(value="custom", name="Custom"))
+            if run_command:
+                if run_command in available_scripts.keys():
+                    default = run_command
+                else:
+                    default = "custom"
+            else:
+                default = choices[0].value
+
+            run_script = await inquirer.select(
                 message="Select script to run your application:",
                 choices=choices,
-                default=run_commands[0] if run_commands else choices[0].value,
+                default=default,
             ).execute_async()
-            run_commands = [run_command]
-
-        else:
+        
+        if run_script == "custom":
             run_command = await inquirer.text(
                 message="Enter command to run your application:",
                 style=style,
                 default=run_command,
             ).execute_async()
-            run_commands = [cmd.strip() for cmd in run_command.split(";")]
+            run_commands = [cmd.strip() for cmd in run_command.split("&")]
+        else:
+            run_commands = [run_script]
 
-    if job_schedule:
+    if job_type in [JobTypeEnum.API, JobTypeEnum.JOB] and job_schedule:
         # Asking for task commands for scheduled jobs
         task_commands = load_script("task.sh")
         if not task_commands:
             task_commands = autodetect_task_commands()
-        task_command = "; ".join(task_commands)
+        task_command = "& ".join(task_commands)
 
         # Ask user to input app run command
         if framework == "node":
@@ -771,7 +857,7 @@ async def commands_flow(job_type: JobTypeEnum):
                 style=style,
                 default=task_command,
             ).execute_async()
-            task_commands = [cmd.strip() for cmd in task_command.split(";")]
+            task_commands = [cmd.strip() for cmd in task_command.split("&")]
 
     if job_type == JobTypeEnum.LAB:
         # For LAB type, create empty *.sh
@@ -788,7 +874,10 @@ async def type_flow() -> Tuple[JobTypeEnum, str]:
     job_type = load_config("job_type", detected_job_type.value)
 
     choices = [
-        Choice(value="api", name="API - Start an API-service (FastAPI/Flask/Node)"),
+        Choice(
+            value="api",
+            name="API/Web - Start an Web-service (e.g. FastAPI/Flask) or Web-site (e.g. Node/React)",
+        ),
         Choice(value="job", name="Job - Run a program (one-time or periodically)"),
         Choice(value="lab", name="Lab - Launch a Lab (Jupyter Notebook)"),
     ]
@@ -807,11 +896,11 @@ async def type_flow() -> Tuple[JobTypeEnum, str]:
         # Ask if user wants to add a schedule job for the API
         current_schedule = load_config("job_schedule", None)
         choices = [
-            Choice(value="no", name="No, just run API"),
+            Choice(value="no", name="No, just run API/WEB application"),
             Choice(value="yes", name="Yes, add scheduled job"),
         ]
         schedule_task = await inquirer.select(
-            message="Would you like to add a scheduled job on top of your API?",
+            message="Would you like to add a scheduled job on top of your API/WEB application?",
             choices=choices,
             default="yes" if current_schedule else "no",
             style=style,
@@ -837,10 +926,13 @@ async def storage_flow():
     # Read previous disk size from config file
     storage_list = load_config("storage", [])
 
+    console.print(
+        "If you have several applications sharing the same files, you can use shared storage"
+    )
     console.print("Shared storage is sync automatically between your jobs")
-    console.print("You can use shared storage located at: [bold]/tmp/<storage_name>[/]")
+    console.print("Your app can use shared storage located at: [bold]/tmp/<storage_name>[/]")
     storage_text = await inquirer.text(
-        message="Enter shared storage names:",
+        message="Enter shared storage names (or press ENTER to skip):",
         style=style,
         default=", ".join(storage_list),
     ).execute_async()
@@ -858,10 +950,12 @@ async def storage_flow():
         console.print(
             "Shared storage is synced automatically between your applications every 5 minutes"
         )
-        console.print("Shared storage is available for your application at:")
+        console.print("Note: Shared storage is available for your application at:")
     for storage in storage_list:
         console.print(f" - /tmp/{storage}")
-
+    if len(storage_list) > 1:
+        console.print()
+        
     return storage_list
 
 
@@ -1063,6 +1157,22 @@ async def config_flow(status: Status, force_config: bool = False) -> dict:
         config["env_file"] = load_config("env_file")
         config["env_values"] = load_config("env_values", {})
 
+    # Services configuration
+    services_value = load_config("services", {})
+    if force_config or not services_value:
+        # Ask user if they want to add redis (y/N)
+        redis_choice = await inquirer.confirm(
+            message="Do you want need Redis for your application?",
+            default="redis" in services_value.keys(),
+        ).execute_async()
+        if redis_choice:
+            services_value["redis"] = {}
+            console.print("Note: Redis will be available at [bold]redis://localhost:6379[/]")
+            console.print()
+        else:
+            services_value.pop("redis", None)
+        config["services"] = services_value
+
     # Validate the complete configuration
     try:
         validate_config(config)
@@ -1181,7 +1291,7 @@ async def run_agent_flow(status: Status):
     3. Sync files
     4. Run process
     """
-    status.update("[bold cyan]Checking the runtime environment...[/]")
+    status.update("[bold cyan]Checking the server (runtime environment)...[/]")
 
     # get agent status
     agent_id = get_agent_id(raise_error=False)
@@ -1192,8 +1302,8 @@ async def run_agent_flow(status: Status):
         or not agent_info.agent_status
         or agent_info.agent_status == AgentStatusEnum.DEAD
     ):
-        console.print("- Environment not found. Creating...")
-        status.update("[bold cyan]Creating the environment...[/]")
+        console.print("- Server not found. Creating...")
+        status.update("[bold cyan]Creating the server...[/]")
 
         agent_info = await api.init_agent_api(
             load_config("compute_size"),
@@ -1208,7 +1318,7 @@ async def run_agent_flow(status: Status):
         )
         agent_id = agent_info.agent_id
         save_config({"agent_id": agent_id})
-        console.print("- Environment initialized. Starting...")
+        console.print("- Server initialized. Starting...")
 
         while agent_info.agent_status != AgentStatusEnum.INIT:
             await asyncio.sleep(1)
@@ -1216,7 +1326,7 @@ async def run_agent_flow(status: Status):
 
     status_text = None
     while agent_info.agent_status == AgentStatusEnum.INIT:
-        status.update("[bold cyan]Starting the environment...[/]")
+        status.update("[bold cyan]Starting the server...[/]")
 
         await asyncio.sleep(1)
         agent_info = await inspect_agent(agent_id)
@@ -1231,8 +1341,8 @@ async def run_agent_flow(status: Status):
 
         # Break if status becomes DEAD during initialization
         if agent_info.agent_status == AgentStatusEnum.DEAD:
-            console.print("[red]Environment failed[/]")
-            print_logs("Agent Logs", agent_info.agent_logs)
+            console.print("[red]Server launch failed[/]")
+            print_logs("Server Logs", agent_info.agent_logs)
             raise click.Abort()
 
     if agent_info.agent_status == AgentStatusEnum.IDLE:
@@ -1241,7 +1351,7 @@ async def run_agent_flow(status: Status):
             raise KeyboardInterrupt
 
         agent_info = await api.run_agent_api(agent_id)
-        console.print("- Environment ready. Starting application...")
+        console.print("- Server ready. Starting application...")
 
     while agent_info.agent_status != AgentStatusEnum.BUSY:
         status.update("[bold cyan]Starting the application...[/]")
@@ -1358,22 +1468,22 @@ async def stop_agent_flow(status: Status, agent_id: str) -> bool:
         # ask user to terminate agent
         terminate_answer = await ask(
             status,
-            "Do you want to terminate runtime environment?",
+            "Do you want to terminate the server?",
             [
                 ("terminate", "Yes, terminate"),
                 ("keep", "No, keep it running"),
             ],
         )
     if terminate_answer == "terminate":
-        status.update("[bold cyan]Terminating environment...[/]")
+        status.update("[bold cyan]Terminating server...[/]")
         agent_info = await api.kill_agent_api(agent_id)
 
     if agent_info.agent_status == AgentStatusEnum.DEAD:
         print_costs(agent_info)
-        console.print("[green]Application stopped. Environment terminated[/]")
+        console.print("[green]Application stopped. Server terminated[/]")
         console.print()
     elif agent_info.agent_status == AgentStatusEnum.IDLE:
-        console.print("[green]Application stopped. Environment still running.[/]")
+        console.print("[green]Application stopped. Server still running.[/]")
         console.print()
 
     return True
@@ -1532,12 +1642,19 @@ def autodetect_build_commands() -> List[str]:
     """
     base_directory = os.getcwd()
     requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    # pyproject_toml_path = os.path.join(base_directory, "pyproject.toml")
+    uv_lock_path = os.path.join(base_directory, "uv.lock")
+    poetry_lock_path = os.path.join(base_directory, "poetry.lock")
     package_json_path = os.path.join(base_directory, "package.json")
 
     build_commands = []
-    if os.path.exists(requirements_txt_path):
+    if os.path.exists(uv_lock_path):
+        build_commands = ["uv sync"]
+    elif os.path.exists(poetry_lock_path):
+        build_commands = ["poetry install"]
+    elif os.path.exists(requirements_txt_path):
         build_commands = ["pip install --no-cache-dir -r requirements.txt"]
-    if os.path.exists(package_json_path):
+    elif os.path.exists(package_json_path):
         package_manager = get_node_package_manager()
         build_commands = [f"{package_manager} install"]
 
@@ -1582,6 +1699,21 @@ def get_node_scripts() -> Dict[str, str]:
     scripts = {f"{package_manager} run {k}": v for k, v in package_json_scripts.items()}
     return scripts
 
+def get_poetry_scripts() -> Dict[str, str]:
+    """
+    Get all scripts from pyproject.toml and detect package manager
+    """
+    base_directory = os.getcwd()
+    pyproject_toml_path = os.path.join(base_directory, "pyproject.toml")
+    if not os.path.exists(pyproject_toml_path):
+        return {}
+
+    with open(pyproject_toml_path, "r") as f:
+        pyproject_toml = toml.load(f)
+
+    poetry_scripts = pyproject_toml.get("tool", {}).get("poetry", {}).get("scripts", {})
+    scripts = {k: v for k, v in poetry_scripts.items()}
+    return scripts
 
 def autodetect_framework() -> str:
     """
@@ -1589,18 +1721,25 @@ def autodetect_framework() -> str:
     """
     base_directory = os.getcwd()
     requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    pyproject_toml_path = os.path.join(base_directory, "pyproject.toml")
     package_json_path = os.path.join(base_directory, "package.json")
 
     framework = "unknown"
     if os.path.exists(requirements_txt_path):
         # Python
-        # if fastapi or flask in requirements.txt, return "fastapi" or "flask"
         with open(requirements_txt_path, "r") as f:
             requirements_content = f.read().lower()
-        if "fastapi" in requirements_content:
-            framework = "fastapi"
-        elif "flask" in requirements_content:
-            framework = "flask"
+        if "uvicorn" in requirements_content:
+            framework = "uvicorn"
+        elif "gunicorn" in requirements_content:
+            framework = "gunicorn"
+    elif os.path.exists(pyproject_toml_path):
+        with open(pyproject_toml_path, "r") as f:
+            pyproject_toml_content = f.read().lower()
+        if "uvicorn" in pyproject_toml_content:
+            framework = "uvicorn"
+        elif "gunicorn" in pyproject_toml_content:
+            framework = "gunicorn"
 
     if os.path.exists(package_json_path):
         # Node
@@ -1614,11 +1753,19 @@ async def autodetect_run_commands() -> List[str]:
     Detect run commands for the application
     """
     base_directory = os.getcwd()
+    pyproject_toml_path = os.path.join(base_directory, "pyproject.toml")
+    uv_lock_path = os.path.join(base_directory, "uv.lock")
+    poetry_lock_path = os.path.join(base_directory, "poetry.lock")
     requirements_txt_path = os.path.join(base_directory, "requirements.txt")
     package_json_path = os.path.join(base_directory, "package.json")
 
     run_commands = []
-    if os.path.exists(requirements_txt_path):
+    if (
+        os.path.exists(requirements_txt_path)
+        or os.path.exists(pyproject_toml_path)
+        or os.path.exists(uv_lock_path)
+        or os.path.exists(poetry_lock_path)
+    ):
         # python
         framework = autodetect_framework()
         main_file = "main"
@@ -1627,15 +1774,12 @@ async def autodetect_run_commands() -> List[str]:
         host = "0.0.0.0"
         workers = 4
 
-        if framework == "fastapi":
+        if framework == "uvicorn":
             run_commands = [
-                f"python -m uvicorn --host {host} --port {port} --workers {workers} {main_file}:{app_name}"
-            ]
-
-        elif framework == "flask":
-            run_commands = [
-                f"python -m gunicorn -b {host}:{port} -w {workers} {main_file}:{app_name}"
+                f"uvicorn --host {host} --port {port} --workers {workers} {main_file}:{app_name}"
             ]
+        elif framework == "gunicorn":
+            run_commands = [f"gunicorn -b {host}:{port} -w {workers} {main_file}:{app_name}"]
         else:
             run_commands = [f"python {main_file}.py"]
 
@@ -1653,11 +1797,19 @@ def autodetect_task_commands() -> List[str]:
     Detect commands for scheduled task
     """
     base_directory = os.getcwd()
+    pyproject_toml_path = os.path.join(base_directory, "pyproject.toml")
+    uv_lock_path = os.path.join(base_directory, "uv.lock")
+    poetry_lock_path = os.path.join(base_directory, "poetry.lock")
     requirements_txt_path = os.path.join(base_directory, "requirements.txt")
     package_json_path = os.path.join(base_directory, "package.json")
 
     task_commands = []
-    if os.path.exists(requirements_txt_path):
+    if (
+        os.path.exists(requirements_txt_path)
+        or os.path.exists(pyproject_toml_path)
+        or os.path.exists(uv_lock_path)
+        or os.path.exists(poetry_lock_path)
+    ):
         task_commands = ["python main.py"]
     if os.path.exists(package_json_path):
         package_manager = get_node_package_manager()
@@ -1674,7 +1826,7 @@ async def autodetect_job_type() -> JobTypeEnum:
     """
 
     framework = autodetect_framework()
-    if framework in ["fastapi", "flask", "node"]:
+    if framework in ["uvicorn", "gunicorn", "node"]:
         return JobTypeEnum.API
     else:
         return JobTypeEnum.JOB
@@ -1805,7 +1957,7 @@ def get_agent_id(raise_error: bool = True) -> str:
     agent_id = load_config("agent_id")
     if not agent_id:
         if raise_error:
-            console.print("[bold red]No environment found[/]")
+            console.print("[bold red]No server found[/]")
             raise click.Abort()
         else:
             return None
@@ -1866,9 +2018,13 @@ def validate_cron_format(cron_string: str) -> bool:
         bool: True if valid, False otherwise
     """
     try:
-        croniter(cron_string, datetime.now())  # Try parsing the cron expression
+        # First validate with croniter
+        croniter(cron_string, datetime.now())
+
+        # Then validate with celery cron converter
+        cron_to_celery_cron(cron_string)
         return True
-    except ValueError:
+    except (ValueError, Exception):
         return False
 
 
@@ -1919,13 +2075,17 @@ def detect_package_manager() -> str:
     """
     Detect the primary package manager for the current project.
     Returns:
-        str: The detected package manager ('uv', 'pip', 'pnpm', 'yarn', 'npm', or None if not detected)
+        str: The detected package manager ('uv', 'poetry', 'pip', 'pnpm', 'yarn', 'npm', or None if not detected)
     """
     base_directory = os.getcwd()
 
     # Check for Python package managers
     if os.path.exists(os.path.join(base_directory, "uv.lock")):
         return "uv"
+    elif os.path.exists(os.path.join(base_directory, "poetry.lock")):
+        return "poetry"
+    # elif os.path.exists(os.path.join(base_directory, "pyproject.toml")):
+    #     return "poetry"
     elif os.path.exists(os.path.join(base_directory, "requirements.txt")):
         return "pip"
 
